;-------------------------------------------------------------------------------
;
; Title:            ds30 Loader for PIC12 and PIC16
;
; File description: user settings and configuration bits
;
; Copyright:        Copyright 2010-2012 Mikael Gustafsson
;
;-------------------------------------------------------------------------------

;-------------------------------------------------------------------------------
;    This file is part of ds30 Loader.
;
;    ds30 Loader is free software: you can redistribute it and/or modify
;    it under the terms of the GNU General Public License as published by
;    the Free Software Foundation.
;
;    ds30 Loader is distributed in the hope that it will be useful,
;    but WITHOUT ANY WARRANTY; without even the implied warranty of
;    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;    GNU General Public License for more details.
;
;    You should have received a copy of the GNU General Public License
;    along with ds30 Loader. If not, see <http://www.gnu.org/licenses/>.
;-------------------------------------------------------------------------------


;-------------------------------------------------------------------------------
; Includes
;-------------------------------------------------------------------------------
        #include        <xc.inc>
        #include        "devices.inc"


;-------------------------------------------------------------------------------
; User preferences
;-------------------------------------------------------------------------------
        #define         FOSC_           16000000    //xxx
        #define         BLINIT          2000        //xxx hello receive timeout [ms]
        #define         HELLOTRIES      2           //xxx number of non hello characters received before branching to the user application
        #define         BLTIME          2000        //xxx data receive timeout [ms]


;-------------------------------------------------------------------------------
; UART settings
;-------------------------------------------------------------------------------
        #define         USE_UART1       1           //xxx uncomment to use uart1
        ;#define        USE_UART2       1           //xxx uncomment to use uart2
        #define         BAUDRATE        115200      //xxx baudrate
        ;#define        USE_ABAUD       1           //xxx auto baud rate detection, only available on enhanced mid-range devices(?)
        #define         USE_BRGH        1           //xxx
        #define         USE_BRG16       1           //xxx 16-bit brg, only available on enhanced mid-range devices(?)

        ;#define        USE_TXENABLE    1           //xxx uncomment to use a tx enable pin
        #ifdef          USE_TXENABLE
            #define     TXE_DELAY       10          //xxx time in us to wait before transmitting after pulling the tx enable pin high
            #define     TRISR_TXE       TRISB       //xxx tris register containing tx enable
            #define     PORTR_TXE       PORTB       //xxx port register containing tx enable
            #define     TRISB_TXE       TRISB0      //xxx tris bit for tx enable
            #define     PORTB_TXE       RB0         //xxx port bit for tx enable
        #endif


;-------------------------------------------------------------------------------
; Advanced settings
;-------------------------------------------------------------------------------
        #define         KICK_WD         1           //xxx uncomment if the watchdog is enabled
        #define         WRITE_VER       1           //xxx do flash write verification
        #define         EWRITE_VER      1           //xxx do eeprom write verification

        #define         BLPL64WP        4           //boot loader placement in 64-word pages from the end of flash


;-------------------------------------------------------------------------------
; Configuration bits, these can be found in the html files
; c:\Program Files\Microchip\xc8\v2.31\docs\chips\
;
; To get a template from MPLAB X IDE, click menu Window\Target memory views\Configuration bits
; and then click the "Generate source code to output" button
;-------------------------------------------------------------------------------

        ; PIC16F1938 example

        ; CONFIG1
        CONFIG  FOSC        = HS
        CONFIG  WDTE        = ON
        CONFIG  PWRTE       = ON
        CONFIG  MCLRE       = ON
        CONFIG  CP          = OFF
        CONFIG  CPD         = OFF
        CONFIG  BOREN       = OFF
        CONFIG  CLKOUTEN    = OFF
        CONFIG  IESO        = OFF
        CONFIG  FCMEN       = OFF

        ; CONFIG2
        CONFIG  WRT         = OFF
        CONFIG  VCAPEN      = OFF
        CONFIG  PLLEN       = ON
        CONFIG  STVREN      = ON
        CONFIG  BORV        = LO
        CONFIG  LVP         = OFF


;-------------------------------------------------------------------------------
; ds30 Loader commercial version
;-------------------------------------------------------------------------------
;-Supports read of flash and EEPROM
;-Supports software UART, CAN and SD Card
;-Read more at www.ds30loader.com


;-------------------------------------------------------------------------------
; End of file
;-------------------------------------------------------------------------------
