;-------------------------------------------------------------------------------
;
; Title:            ds30 Loader for PIC12 and PIC16
;
; File description: user settings and configuration bits
;
; Copyright:        Copyright 2010-2012 Mikael Gustafsson
;
;-------------------------------------------------------------------------------

;-------------------------------------------------------------------------------
;    This file is part of ds30 Loader.
;
;    ds30 Loader is free software: you can redistribute it and/or modify
;    it under the terms of the GNU General Public License as published by
;    the Free Software Foundation.
;
;    ds30 Loader is distributed in the hope that it will be useful,
;    but WITHOUT ANY WARRANTY; without even the implied warranty of
;    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;    GNU General Public License for more details.
;
;    You should have received a copy of the GNU General Public License
;    along with ds30 Loader. If not, see <http://www.gnu.org/licenses/>.
;-------------------------------------------------------------------------------


;-------------------------------------------------------------------------------
; Device
;-------------------------------------------------------------------------------
        LIST            P=16F1938


;-------------------------------------------------------------------------------
; Includes
;-------------------------------------------------------------------------------
        #include        "devices.inc"


;-------------------------------------------------------------------------------
; User preferences
;-------------------------------------------------------------------------------
        #define         FOSC_           16000000    ;xxx
        #define         BLINIT          2000        ;xxx hello receive timeout [ms]
        #define         HELLOTRIES      2           ;xxx number of non hello characters received before branching to the user application
        #define         BLTIME          2000        ;xxx data receive timeout [ms]


;-------------------------------------------------------------------------------
; UART settings
;-------------------------------------------------------------------------------
        #define         USE_UART1       1           ;xxx uncomment to use uart1
        ;#define        USE_UART2       1           ;xxx uncomment to use uart2
        #define         BAUDRATE        115200      ;xxx baudrate
        ;#define        USE_ABAUD       1           ;xxx auto baud rate detection, only available on enhanced mid-range devices(?)
        #define         USE_BRGH        1           ;xxx
        #define         USE_BRG16       1           ;xxx 16-bit brg, only available on enhanced mid-range devices(?)

        ;#define        USE_TXENABLE    1           ;xxx uncomment to use a tx enable pin
        #ifdef          USE_TXENABLE
        #define         TXE_DELAY       10          ;xxx time in us to wait before transmitting after pulling the tx enable pin high
        #define         TRISR_TXE       TRISB       ;xxx tris register containing tx enable
        #define         PORTR_TXE       PORTB       ;xxx port register containing tx enable
        #define         TRISB_TXE       TRISB0      ;xxx tris bit for tx enable
        #define         PORTB_TXE       RB0         ;xxx port bit for tx enable
        #endif


;-------------------------------------------------------------------------------
; Advanced settings
;-------------------------------------------------------------------------------
        #define         KICK_WD         1           ;xxx uncomment if the watchdog is enabled
        #define         WRITE_VER       1           ;xxx do flash write verification
        #define         EWRITE_VER      1           ;xxx do eeprom write verification

        #define         BLPL64WP        4           ;boot loader placement in 64-word pages from the end of flash


;-------------------------------------------------------------------------------
; Configuration bits, these macros can be found at the end of the inc-files located in
; c:\Program Files (x86)\Microchip\MPLABX\v5.35\mpasmx\
;
; To get a template from MPLAB X IDE, click menu Window\Target memory views\Configuration bits
; and then click the "Generate source code to output" button
;-------------------------------------------------------------------------------

        ; Example for 16F1938
        __CONFIG _CONFIG1, _FOSC_HS & _WDTE_ON & _PWRTE_ON & _MCLRE_ON & _CP_OFF & _CPD_OFF & _BOREN_OFF & _CLKOUTEN_OFF & _IESO_OFF & _FCMEN_OFF
        __CONFIG _CONFIG2, _WRT_OFF & _VCAPEN_OFF & _PLLEN_ON & _STVREN_ON & _BORV_LO & _LVP_OFF

        ; Example for PIC16F877A
        ;__CONFIG        _FOSC_EXTRC & _WDTE_ON & _PWRTE_OFF & _BOREN_ON & _LVP_ON & _CPD_OFF & _WRT_OFF & _CP_OFF

        ; Example for PIC16F18456
        ;__CONFIG _CONFIG1, _FEXTOSC_OFF & _RSTOSC_HFINT32 & _CLKOUTEN_OFF & _CSWEN_OFF & _FCMEN_ON
        ;__CONFIG _CONFIG2, _MCLRE_ON & _PWRTS_OFF & _LPBOREN_OFF & _BOREN_OFF & _BORV_LO & _ZCD_OFF & _PPS1WAY_OFF & _STVREN_ON
        ;__CONFIG _CONFIG3, _WDTCPS_WDTCPS_31 & _WDTE_ON & _WDTCWS_WDTCWS_7 & _WDTCCS_SC
        ;__CONFIG _CONFIG4, _BBSIZE_BB512 & _BBEN_OFF & _SAFEN_OFF & _WRTAPP_OFF & _WRTB_OFF & _WRTC_OFF & _WRTD_OFF & _WRTSAF_OFF & _LVP_ON
        ;__CONFIG _CONFIG5, _CP_OFF


;-------------------------------------------------------------------------------
; ds30 Loader commercial version
;-------------------------------------------------------------------------------
;-Supports read of flash and EEPROM
;-Supports software UART, CAN and SD Card
;-Read more at www.ds30loader.com


;-------------------------------------------------------------------------------
; End of file
;-------------------------------------------------------------------------------
