;-------------------------------------------------------------------------------
;
; Title:            ds30 loader for 16-bit PIC/dsPIC
;
; File description: user settings and configuration bits for PIC24 and dsPIC
;
; Copyright:        Copyright 2011-2020 DigSol Sweden AB
;
;-------------------------------------------------------------------------------

;-------------------------------------------------------------------------------
;    This file is part of ds30 Loader.
;
;    ds30 Loader is free software: you can redistribute it and/or modify
;    it under the terms of the GNU General Public License as published by
;    the Free Software Foundation.
;
;    ds30 Loader is distributed in the hope that it will be useful,
;    but WITHOUT ANY WARRANTY; without even the implied warranty of
;    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;    GNU General Public License for more details.
;
;    You should have received a copy of the GNU General Public License
;    along with ds30 Loader. If not, see <http://www.gnu.org/licenses/>.
;-------------------------------------------------------------------------------



;-------------------------------------------------------------------------------
; Device
;-------------------------------------------------------------------------------
        ;.equ __24F16KA102,                 1           ;xxx uncomment and change if using PIC24F device
        .equ __24FJ128GA010,                1           ;xxx uncomment and change if using PIC24FJ device
        ;.equ __24HJ128GP504,               1           ;xxx uncomment and change if using PIC24HJ device
        ;.equ __30F4013,                    1           ;xxx uncomment and change if using dsPIC30F device
        ;.equ __33FJ256GP710A,              1           ;xxx uncomment and change if using dsPIC33FJ device


;-------------------------------------------------------------------------------
; Includes
;-------------------------------------------------------------------------------
        .include    "devices.inc"


;-------------------------------------------------------------------------------
; User preferences
;-------------------------------------------------------------------------------
        .equiv          FCY,                16000000    ;xxx speed of internal cycle clock[Hz], used to calculate uart brg and delay
        .equiv          BLINIT,             3000        ;xxx hello receive timeout [ms]
        .equiv          HELLOTRIES,         2           ;xxx number of non hello characters received before branching to the user application
        .equiv          BLTIME,             3000        ;xxx data receive timeout [ms]


;-------------------------------------------------------------------------------
; UART settings
;-------------------------------------------------------------------------------
        ;.equiv         USE_UART1,          1           ;xxx uncomment to use uart1
        .equiv          USE_UART2,          1           ;xxx uncomment to use uart2
        ;.equiv         USE_UART3,          1           ;xxx uncomment to use uart3
        ;.equiv         USE_UART4,          1           ;xxx uncomment to use uart4
        ;.equ           USE_ALTIO,          1           ;xxx uncomment to use uart 1 alternative i/o, only for dsPIC30F
        .equiv          BAUDRATE,           115200      ;xxx baudrate
        ;.equiv         USE_ABAUD,          1           ;xxx uncomment to use auto baud rate detection, READ ERRATA FIRST
        .equiv          USE_BRGH,           1           ;xxx uncomment to use high baud rates, READ ERRATA FIRST, not available for PIC24F

        ;.equiv         USE_TXENABLE,       1           ;xxx uncomment to use a tx enable pin
        .ifdef USE_TXENABLE
            .equ        TXE_DELAY,          10          ;xxx time in us to wait before transmitting after pulling the tx enable pin high
            .equiv      TRISR_TXE,          TRISA       ;xxx tris register containing tx enable
            .equiv      LATR_TXE,           LATA        ;xxx port register containing tx enable
            .equiv      TRISB_TXE,          TRISA1      ;xxx tris bit for tx enable
            .equiv      LATB_TXE,           RA1         ;xxx port bit for tx enable
        .endif


;-------------------------------------------------------------------------------
; Advanced settings
;-------------------------------------------------------------------------------
        ;.equiv         KICK_WD,            1           ;xxx uncomment to kick the wd in the rx loop, ONLY enable if watchdog is enabled
        .equiv          WRITE_VER,          1           ;xxx do flash write verification
        .equiv          EWRITE_VER,         1           ;xxx do eeprom write verification
        .equiv          PROT_GOTO,          1           ;protect goto at 0x00
        .equiv          PROT_BL,            1           ;protect bootloader

        .ifdef    IS_24F
            .equiv      BLPLP,              7           ;bootloader placement, pages from end
            .equiv      BLSIZEP,            7           ;bootloader size [pages], used by bootloader protection
        .endif

        .ifdef    IS_24FJ
            .equiv      BLPLP,              2           ;bootloader placement, pages from end
            .equiv      BLSIZEP,            1           ;bootloader size [pages], used by bootloader protection
        .endif

        .ifdef IS_24HJ
            .equiv      BLPLP,              1           ;bootloader placement, pages from end
            .equiv      BLSIZEP,            1           ;bootloader size [pages], used by bootloader protection
        .endif

        .ifdef    IS_30F
            .equiv      BLPLP,              9           ;bootloader placement, pages from end
            .equiv      BLSIZEP,            9           ;bootloader size [pages], used by bootloader protection
        .endif

        .ifdef IS_33FJ
            .equiv      BLPLP,              1           ;bootloader placement, pages from end
            .equiv      BLSIZEP,            1           ;bootloader size [pages], used by bootloader protection
        .endif


;-------------------------------------------------------------------------------
; Configuration bits, these macros can be found at the end of the inc-files located at
; c:\Program Files\Microchip\xc16\v1.61\support\dsPIC33F\inc\
;-------------------------------------------------------------------------------
        
        
;-------------------------------------------------------------------------------
; End of file
;-------------------------------------------------------------------------------
