;-------------------------------------------------------------------------------
;
; Title:            ds30 Loader for PIC18
;
; File description: user settings and configuration bits
;
; Copyright:        Copyright 2009-2020, DigSol Sweden AB
;
;-------------------------------------------------------------------------------

;-------------------------------------------------------------------------------
;    This file is part of ds30 Loader.
;
;    ds30 Loader is free software: you can redistribute it and/or modify
;    it under the terms of the GNU General Public License as published by
;    the Free Software Foundation.
;
;    ds30 Loader is distributed in the hope that it will be useful,
;    but WITHOUT ANY WARRANTY; without even the implied warranty of
;    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;    GNU General Public License for more details.
;
;    You should have received a copy of the GNU General Public License
;    along with ds30 Loader. If not, see <http://www.gnu.org/licenses/>.
;-------------------------------------------------------------------------------



;-------------------------------------------------------------------------------
; Device
;-------------------------------------------------------------------------------
        processor       18F66K80                    ;xxx


;-------------------------------------------------------------------------------
; Includes
;-------------------------------------------------------------------------------
        #include "devices.inc"


;-------------------------------------------------------------------------------
; User preferences
;-------------------------------------------------------------------------------
        #define         OSCF            40000000    //xxx oscillator frequency (including pll)
        #define         BLINIT          2000        //xxx hello receive timeout [ms]
        #define         HELLOTRIES      2           //xxx number of non hello characters received before branching to the user application
        #define         BLTIME          2000        //xxx data receive timeout [ms]


;-------------------------------------------------------------------------------
; UART settings
;-------------------------------------------------------------------------------
        #define         USE_UART1       1           //xxx uncomment to use uart1
        ;#define        USE_UART2       1           //xxx uncomment to use uart2
        #define         BAUDRATE        115200      //xxx baudrate
        ;#define        USE_ABAUD       1           //xxx uncomment to use auto baud rate detection, READ ERRATA FIRST
        #define         USE_BRG16       1           //xxx uncomment to use 16-bit brg

        ;#define        USE_TXENABLE    1           //xxx uncomment to use a tx enable pin
        #ifdef USE_TXENABLE
            #define     TXE_DELAY       10          //xxx time in us to wait before transmitting after pulling the tx enable pin high
            #define     TRISR_TXE       TRISD       //xxx tris register containing tx enable
            #define     LATR_TXE        LATD        //xxx port register containing tx enable
            #define     TRISB_TXE       TRISD0      //xxx tris bit for tx enable
            #define     LATB_TXE        RD0         //xxx port bit for tx enable
        #endif


;-------------------------------------------------------------------------------
; Advanced settings
;-------------------------------------------------------------------------------
        #define         KICK_WD         1           //xxx uncomment to kick the wd in the rx loop, only enable if the watchdog is enabled
        #define         PROT_GOTO       1           //xxx protect goto at 0x00
        #define         PROT_BL         1           //xxx protect bootloader
        #define         WRITE_VER       1           //do flash write verification
        #define         EWRITE_VER      1           //do eeprom write verification

        #ifdef IS_18F
            #define     BLPL64WP        4                           //bootloader placement in 64 word pages from end
            #define     BLSIZE64WP      4                           //bootloader size in 64 word pages, used by bootloader protection

            #define     BLPLP           (BLPL64WP * 64/PAGESIZEW)   //bootloader placement, pages from end
            #define     BLSIZEP         (BLSIZE64WP * 64/PAGESIZEW) //bootloader size [pages], used by bootloader protection
        #endif

        #ifdef IS_18FJ
            #define     BLPLP512WP      2                           //bootloader placement in 512 word pages from end
            #define     BLSIZE512WP     1                           //bootloader size in 512 word pages, used by bootloader protection

            #define     BLPLP           (BLPL64WP * 512/PAGESIZEW)  //bootloader placement, pages from end
            #define     BLSIZEP         (BLSIZE64WP * 512/PAGESIZEW)//bootloader size [pages], used by bootloader protection
        #endif


;-------------------------------------------------------------------------------
; Configuration bits, these macros can be found at the end of the inc-files located in
; C:\Program Files\Microchip\MPASM Suite\
;
; These can also be set in MPLAB IDE instead, they are found in Configure->Configuration bits...
;-------------------------------------------------------------------------------

        ; xxx, 18F66K80 example
        config          RETEN           = OFF
        config          INTOSCSEL       = LOW
        config          SOSCSEL         = LOW
        config          XINST           = OFF
        config          FOSC            = HS1
        config          PLLCFG          = OFF
        config          FCMEN           = OFF
        config          IESO            = OFF
        config          PWRTEN          = OFF
        config          BOREN           = OFF
        config          BORV            = 3
        config          BORPWR          = MEDIUM
        config          WDTEN           = OFF
        config          WDTPS           = 32768
        config          CANMX           = PORTE
        config          T0CKMX          = PORTG
        config          T3CKMX          = PORTB
        ;config          MSSPMSK         = MSK7
        config          MCLRE           = ON
        config          STVREN          = ON

        config          BBSIZ           = BB2K
        config          CP0             = OFF
        config          CP1             = OFF
        config          CP2             = OFF
        config          CP3             = OFF
        config          CPB             = OFF
        config          CPD             = OFF
        config          WRT0            = OFF
        config          WRT1            = OFF
        config          WRT2            = OFF
        config          WRT3            = OFF
        config          WRTC            = OFF
        config          WRTB            = OFF
        config          WRTD            = OFF
        config          EBTR0           = OFF
        config          EBTR1           = OFF
        config          EBTR2           = OFF
        config          EBTR3           = OFF
        config          EBTRB           = OFF


;-------------------------------------------------------------------------------
; ds30 Loader commercial version
;-------------------------------------------------------------------------------
;-Supports read of flash and EEPROM
;-Supports software UART, CAN, SD Card
;-Available with encryption
;-Read more at www.ds30loader.com


;-------------------------------------------------------------------------------
; End of file
;-------------------------------------------------------------------------------
